# pytch

### Pytch Yields Technical Characteristics Hastily

<br/>

![](https://lh3.googleusercontent.com/pw/AIL4fc_Z8qwS2and18m9T_TictE9eg82GOBcLVCsdvM5rJSt1ytndTxPbYtbkLVOrwiVev-Kq19oc5ge2c-dVKi65ec8FOF5__IceoUDGE-tGR0HxpO-Wa-j8peliYgIpedMdh-3SdkB1dNd_kG6uN3YghYH=w577-h811-s-no)

## Description

Pytch is a small and efficient fetch script written in Python with no dependencies. It has a relatively fast execution time of ~20ms and is tested on Python versions 3.7 or newer and PyPy (it will probably work on earlier versions but has not been tested as such). It is configured by editing its source code, though the Python used is relatively simple and readable. Rest assured, if you do not understand something, open up an issue and I will be happy to explain it to you. At its current state, Pytch only supports a few popular Linux distributions and macOS (see [this function](https://github.com/kritdass/pytch/blob/main/src/pytch/funcs.py#L151) for a list though most are not tested). If support is lacking for your distribution, please open up an issue and I will add support for your distribution. Pull requests are welcome and encouraged, please do not hesitate.

## Installation

```
  $ pip install pytch-fetch
```
You will need a [Nerd Font](https://www.nerdfonts.com/) to see the icons. I use [JetFlow](https://github.com/kritdass/JetFlow).

## Acknowlegements

- [@ssleert](https://github.com/ssleert) for creating [nitch](https://github.com/ssleert/nitch), which inspired this project
- [@dylanaraps](https://github.com/dylanaraps) for creating [neofetch](https://github.com/dylanaraps/neofetch), which was a source of reference and logos
- [@willrson](https://github.com/willrson) and [@kapoorkrish](https://github.com/kapoorkrish) for helping add macOS support
